FetchBuilderController<R> class

Inheritance

Constructors

FetchBuilderController()

Properties

hashCode int
The hash code for this object.
no setterinherited
isMounted bool
Whether the controller is mounted to a FetchBuilder.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh({bool? clearDataFirst, FetchErrorDisplayMode? errorDisplayMode}) Future<R?>
Refresh data by re-running the FetchBuilder.task. Return the result of the task, or null if task throws. Throws if controller is not mounted. Use isMounted to check if controller is mounted before use.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited