refresh method
Refresh data by re-running the FetchBuilder.task. Return the result of the task, or null if task throws. Throws if controller is not mounted. Use isMounted to check if controller is mounted before use.
Implementation
@override
Future<R?> refresh({bool? clearDataFirst, FetchErrorDisplayMode? errorDisplayMode}) =>
_state!._fetch(clearDataFirst: clearDataFirst, errorDisplayMode: errorDisplayMode);