extra library
Classes
- ActivityBarrier
- A widget that add an activity indicator overlay that prevents the user from interacting with widgets behind itself.
- ClearFocusBackground
- FadedAnimatedSwitcher
- FillRemainsScrollView
- GuardedForm
-
A Form that tracks for changes and may prevent pop.
Current implementation just track if form has been modified once (calling
Form.save()doesn't reset status).
Extensions
Functions
-
scrollToFirstInvalidField(
BuildContext formContext) → void -
Scrolls to the first invalid FormField in the subtree rooted at
formContext. Must be called afterForm.validateso that FormFieldState.hasError is up to date.
Typedefs
-
ParameterizedAsyncTask<
T, R> = Future< R> Function(T? param)