FetchBuilderControllerBase<T, R> class
abstract
A controller for an FetchBuilder.
Only support one widget per controller. If multiple widget are using the same controller, only the last one will work.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMounted → bool
-
Whether the controller is mounted to a FetchBuilder.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< R?> - Refresh data by re-running the FetchBuilder.task. Return the result of the task, or null if task throws. Throws if controller is not mounted. Use isMounted to check if controller is mounted before use.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited